@@ -5,7 +5,7 @@ ConvertType is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -109,7 +109,7 @@ color_from_mono_hsv(struct converttparams *p)
                    channel->dsize, channel->wcs, 0, p->cp.minmapsize,
                    p->cp.quietmmap, "BLUE", NULL, "Blue color channel.");
 
-  /* Start the conversion. Note that the "Choroma" (`C') is fixed by our
+  /* Start the conversion. Note that the "Choroma" ('C') is fixed by our
      definition. */
   r=R->array;
   g=G->array;
@@ -195,7 +195,7 @@ color_from_mono_sls(struct converttparams *p)
                    channel->dsize, channel->wcs, 0, p->cp.minmapsize,
                    p->cp.quietmmap, "BLUE", NULL, "Blue color channel.");
 
-  /* Start the conversion. Note that the "Choroma" (`C') is fixed by our
+  /* Start the conversion. Note that the "Choroma" ('C') is fixed by our
      definition. */
   r=R->array;
   g=G->array;
@@ -463,7 +463,7 @@ color_from_mono_viridis(struct converttparams *p)
                    channel->dsize, channel->wcs, 0, p->cp.minmapsize,
                    p->cp.quietmmap, "BLUE", NULL, "Blue color channel.");
 
-  /* Start the conversion. Note that the "Choroma" (`C') is fixed by our
+  /* Start the conversion. Note that the "Choroma" ('C') is fixed by our
      definition. */
   r=R->array;
   g=G->array;
@@ -869,12 +869,12 @@ color_rgb_to_hsv(struct converttparams *p)
               if( *h<0.0 ) *h += 360.0;
             }
           else
-            /* When `max==0', then *r=*g=*b=0, so s=h=0. */
+            /* When 'max==0', then *r=*g=*b=0, so s=h=0. */
             *s=*h=0.0;
         }
       else
         /* When there is no difference, then its actually a grayscale
-           dataset, so `*v' is the only parameter that matters. */
+           dataset, so '*v' is the only parameter that matters. */
         *s=*h=0.0;
 
 
