@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -190,8 +190,8 @@ struct mkprofparams
   char       *mergedimgname;  /* Name of merged image.                    */
   int                  nwcs;  /* for WCSLIB: no. coord. representations.  */
   struct wcsprm        *wcs;  /* WCS information for this dataset.        */
-  size_t               ndim;  /* Number of dimensions (for `nomerged').   */
-                              /* We can't put it in `out' because it is   */
+  size_t               ndim;  /* Number of dimensions (for 'nomerged').   */
+                              /* We can't put it in 'out' because it is   */
                               /* meaning ful there.                       */
 };
 
