@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -81,7 +81,10 @@ enum option_keys_enum
   UI_KEY_RCOL,
   UI_KEY_NCOL,
   UI_KEY_PCOL,
+  UI_KEY_P2COL,
+  UI_KEY_P3COL,
   UI_KEY_QCOL,
+  UI_KEY_Q2COL,
   UI_KEY_MCOL,
   UI_KEY_TCOL,
   UI_KEY_CRPIX,
