@@ -5,7 +5,7 @@ NoiseChisel is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -213,7 +213,7 @@ noisechisel_output(struct noisechiselparams *p)
 
   /* Let the user know that the output is written. */
   if(!p->cp.quiet)
-    printf("  - Output written to `%s'.\n", p->cp.output);
+    printf("  - Output written to '%s'.\n", p->cp.output);
 }
 
 
@@ -248,28 +248,14 @@ noisechisel(struct noisechiselparams *p)
   /* Remove false detections. */
   detection(p);
 
-  /* If we have any detections, find the Sky value and subtract it from the
-     input and convolved images. */
-  if(p->numdetections)
-    {
-      /* Find the final Sky and Sky STD values. */
-      sky_and_std(p, p->skyname);
+  /* Find the final Sky and Sky STD values. */
+  sky_and_std(p, p->skyname);
 
-      /* Abort if the user only wanted to see until this point.*/
-      if(p->skyname && !p->continueaftercheck)
-        ui_abort_after_check(p, p->skyname, NULL,
-                             "derivation of final Sky (and its STD) value");
+  /* Abort if the user only wanted to see until this point.*/
+  if(p->skyname && !p->continueaftercheck)
+    ui_abort_after_check(p, p->skyname, NULL,
+                         "derivation of final Sky (and its STD) value");
 
-      /* Write the output. */
-      noisechisel_output(p);
-    }
-  else
-    {
-      if(p->cp.quiet)
-        error(0, 0, "no output file created: no detections could found "
-              "in `%s' with given parameters", p->inputname);
-      else
-        gal_timing_report(NULL, "NO OUTPUT FILE CREATED (try with "
-                          "`--checkdetection' to see why)", 1);
-    }
+  /* Write the output. */
+  noisechisel_output(p);
 }
