@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2019, Free Software Foundation, Inc.
+Copyright (C) 2016-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -31,6 +31,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/list.h>
 #include <gnuastro/blank.h>
+#include <gnuastro/units.h>
 #include <gnuastro/qsort.h>
 #include <gnuastro/pointer.h>
 #include <gnuastro/threads.h>
@@ -90,10 +91,10 @@ arithmetic_check_float_input(gal_data_t *in, int operator, char *numstr)
     default:
       error(EXIT_FAILURE, 0, "the %s operator can only accept single or "
             "double precision floating point numbers as its operand. The "
-            "%s operand has type %s. You can use the `float' or `double' "
+            "%s operand has type %s. You can use the 'float' or 'double' "
             "operators before this operator to explicitly convert to the "
             "desired precision floating point type. If the operand was "
-            "originally a typed number (string of characters), add an `f' "
+            "originally a typed number (string of characters), add an 'f' "
             "after it so it is directly read into the proper precision "
             "floating point number (based on the number of non-zero "
             "decimals it has)", gal_arithmetic_operator_string(operator),
@@ -396,6 +397,44 @@ arithmetic_abs(int flags, gal_data_t *in)
             "UNIARY_FUNCTION_ON_ELEMENT", in->type);                    \
     }
 
+#define UNIARY_FUNCTION_ON_ELEMENT_OUTPUT_STRING(OP)                    \
+  switch(in->type)                                                      \
+    {                                                                   \
+    case GAL_TYPE_UINT8:                                                \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, uint8_t,  OP)             \
+        break;                                                          \
+    case GAL_TYPE_INT8:                                                 \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, int8_t,   OP)             \
+        break;                                                          \
+    case GAL_TYPE_UINT16:                                               \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, uint16_t, OP)             \
+        break;                                                          \
+    case GAL_TYPE_INT16:                                                \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, int16_t,  OP)             \
+        break;                                                          \
+    case GAL_TYPE_UINT32:                                               \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, uint32_t, OP)             \
+        break;                                                          \
+    case GAL_TYPE_INT32:                                                \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, int32_t,  OP)             \
+        break;                                                          \
+    case GAL_TYPE_UINT64:                                               \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, uint64_t, OP)             \
+        break;                                                          \
+    case GAL_TYPE_INT64:                                                \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, int64_t,  OP)             \
+        break;                                                          \
+    case GAL_TYPE_FLOAT32:                                              \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, float,    OP)             \
+      break;                                                            \
+    case GAL_TYPE_FLOAT64:                                              \
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT(char *, double,   OP)             \
+      break;                                                            \
+    default:                                                            \
+      error(EXIT_FAILURE, 0, "%s: type code %d not recognized",         \
+            "UNIARY_FUNCTION_ON_ELEMENT_OUTPUT_STRING", in->type);      \
+    }
+
 #define UNIARY_FUNCTION_ON_ELEMENT(OP)                                  \
   switch(in->type)                                                      \
     {                                                                   \
@@ -434,6 +473,13 @@ arithmetic_abs(int flags, gal_data_t *in)
             "UNIARY_FUNCTION_ON_ELEMENT", in->type);                    \
     }
 
+
+#define UNIFUNC_RUN_FUNCTION_ON_ELEMENT_STRING(OT, OP){                 \
+    OT *oa=o->array;                                                    \
+    char **ia=in->array, **iaf=ia + in->size;                           \
+    do *oa++ = OP(*ia++); while(ia<iaf);                                \
+}
+
 static gal_data_t *
 arithmetic_unary_function(int operator, int flags, gal_data_t *in)
 {
@@ -446,7 +492,11 @@ arithmetic_unary_function(int operator, int flags, gal_data_t *in)
      point). So even if the user requested inplace opereation, if its not a
      floating point type, its not useful.*/
   if( (flags & GAL_ARITHMETIC_INPLACE)
-      && (in->type==GAL_TYPE_FLOAT32 || in->type==GAL_TYPE_FLOAT64) )
+      && (in->type==GAL_TYPE_FLOAT32 || in->type==GAL_TYPE_FLOAT64)
+      && (operator != GAL_ARITHMETIC_OP_RA_TO_DEGREE
+      &&  operator != GAL_ARITHMETIC_OP_DEC_TO_DEGREE
+      &&  operator != GAL_ARITHMETIC_OP_DEGREE_TO_RA
+      &&  operator != GAL_ARITHMETIC_OP_DEGREE_TO_DEC ) )
     inplace=1;
 
   if(inplace)
@@ -459,6 +509,16 @@ arithmetic_unary_function(int operator, int flags, gal_data_t *in)
       otype = ( in->type==GAL_TYPE_FLOAT64
                 ? GAL_TYPE_FLOAT64
                 : GAL_TYPE_FLOAT32 );
+
+      /* Check for operators which have fixed output types */
+      if ( operator == GAL_ARITHMETIC_OP_RA_TO_DEGREE ||
+           operator == GAL_ARITHMETIC_OP_DEC_TO_DEGREE )
+        otype = GAL_TYPE_FLOAT64;
+
+      if (operator == GAL_ARITHMETIC_OP_DEGREE_TO_RA ||
+          operator == GAL_ARITHMETIC_OP_DEGREE_TO_DEC)
+        otype = GAL_TYPE_STRING;
+
       o = gal_data_alloc(NULL, otype, in->ndim, in->dsize, in->wcs,
                          0, in->minmapsize, in->quietmmap,
                          NULL, NULL, NULL);
@@ -479,6 +539,22 @@ arithmetic_unary_function(int operator, int flags, gal_data_t *in)
       UNIARY_FUNCTION_ON_ELEMENT( log10 );
       break;
 
+    case GAL_ARITHMETIC_OP_RA_TO_DEGREE:
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT_STRING(double, gal_units_ra_to_degree);
+      break;
+
+    case GAL_ARITHMETIC_OP_DEC_TO_DEGREE:
+      UNIFUNC_RUN_FUNCTION_ON_ELEMENT_STRING(double, gal_units_dec_to_degree);
+      break;
+
+    case GAL_ARITHMETIC_OP_DEGREE_TO_RA:
+      UNIARY_FUNCTION_ON_ELEMENT_OUTPUT_STRING(gal_units_degree_to_ra);
+      break;
+
+    case GAL_ARITHMETIC_OP_DEGREE_TO_DEC:
+      UNIARY_FUNCTION_ON_ELEMENT_OUTPUT_STRING(gal_units_degree_to_dec);
+      break;
+
     default:
       error(EXIT_FAILURE, 0, "%s: operator code %d not recognized",
             __func__, operator);
@@ -486,10 +562,10 @@ arithmetic_unary_function(int operator, int flags, gal_data_t *in)
 
 
   /* Clean up. Note that if the input arrays can be freed, and any of right
-     or left arrays needed conversion, `UNIFUNC_CONVERT_TO_COMPILED_TYPE'
-     has already freed the input arrays, and we only have `r' and `l'
+     or left arrays needed conversion, 'UNIFUNC_CONVERT_TO_COMPILED_TYPE'
+     has already freed the input arrays, and we only have 'r' and 'l'
      allocated in any case. Alternatively, when the inputs shouldn't be
-     freed, the only allocated spaces are the `r' and `l' arrays if their
+     freed, the only allocated spaces are the 'r' and 'l' arrays if their
      types weren't compiled for binary operations, we can tell this from
      the pointers: if they are different from the original pointers, they
      were allocated. */
@@ -504,7 +580,7 @@ arithmetic_unary_function(int operator, int flags, gal_data_t *in)
 
 
 
-/* Call functions in the `gnuastro/statistics' library. */
+/* Call functions in the 'gnuastro/statistics' library. */
 static gal_data_t *
 arithmetic_from_statistics(int operator, int flags, gal_data_t *input)
 {
@@ -550,10 +626,94 @@ arithmetic_from_statistics(int operator, int flags, gal_data_t *input)
 
 
 
+/***********************************************************************/
+/***************                  Metadata                **************/
+/***********************************************************************/
+
+/* The size operator. Reports the size along a given dimension. */
+static gal_data_t *
+arithmetic_size(int operator, int flags, gal_data_t *in, gal_data_t *arg)
+{
+  size_t one=1, arg_val;
+  gal_data_t *usearg=NULL, *out=NULL;
+
+  /* Sanity checks on argument (dimension number): it should be an integer,
+     and have a size of 1. */
+  if(arg->type==GAL_TYPE_FLOAT32 || arg->type==GAL_TYPE_FLOAT64)
+    error(EXIT_FAILURE, 0, "%s: size operator's dimension argument"
+          "must have an integer type", __func__);
+  if(arg->size!=1)
+    error(EXIT_FAILURE, 0, "%s: size operator's dimension argument"
+          "must be a single number, but it has %zu elements", __func__,
+          arg->size);
+
+
+  /* Convert 'arg' to 'size_t' and read it. Note that we can only free the
+     'arg' array (while changing its type), when the freeing flag has been
+     set. */
+  if(flags & GAL_ARITHMETIC_FREE)
+    {
+      arg=gal_data_copy_to_new_type_free(arg, GAL_TYPE_SIZE_T);
+      arg_val=*(size_t *)(arg->array);
+      gal_data_free(arg);
+    }
+  else
+    {
+      usearg=gal_data_copy_to_new_type(arg, GAL_TYPE_SIZE_T);
+      arg_val=*(size_t *)(usearg->array);
+      gal_data_free(usearg);
+    }
+
+
+  /* Sanity checks on the value of the given argument.*/
+  if(arg_val>in->ndim)
+    error(EXIT_FAILURE, 0, "%s: size operator's dimension argument "
+          "(given %zu) cannot be larger than the dimensions of the "
+          "given input (%zu)", __func__, arg_val, in->ndim);
+  if(arg_val==0)
+    error(EXIT_FAILURE, 0, "%s: size operator's dimension argument "
+          "(given %zu) cannot be zero: dimensions are counted from 1",
+          __func__, arg_val);
+
+
+  /* Allocate the output array and write the desired dimension. Note that
+     'dsize' is in the C order, while the output must be in FITS/Fortran
+     order. Also that C order starts from 0, while the FITS order starts
+     from 1. */
+  out=gal_data_alloc(NULL, GAL_TYPE_SIZE_T, 1, &one, NULL, 0,
+                     in->minmapsize, 0, NULL, NULL, NULL);
+  *(size_t *)(out->array)=in->dsize[in->ndim-arg_val];
+
+
+  /* Clean up and return */
+  if(flags & GAL_ARITHMETIC_FREE)
+    gal_data_free(in);
+  return out;
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 /***********************************************************************/
 /***************                  Where                   **************/
 /***********************************************************************/
-/* When the `iftrue' dataset only has one element and the element is blank,
+/* When the 'iftrue' dataset only has one element and the element is blank,
    then it will be replaced with the blank value of the type of the output
    data. */
 #define DO_WHERE_OPERATION(ITT, OT) {                                   \
@@ -595,7 +755,7 @@ arithmetic_from_statistics(int operator, int flags, gal_data_t *input)
     case GAL_TYPE_FLOAT64:  DO_WHERE_OPERATION( double,   OT);  break;  \
     default:                                                            \
       error(EXIT_FAILURE, 0, "%s: type code %d not recognized for the " \
-            "`iftrue' dataset", "WHERE_OUT_SET", iftrue->type);         \
+            "'iftrue' dataset", "WHERE_OUT_SET", iftrue->type);         \
     }
 
 
@@ -612,8 +772,8 @@ arithmetic_where(int flags, gal_data_t *out, gal_data_t *cond,
   /* The condition operator has to be unsigned char. */
   if(cond->type!=GAL_TYPE_UINT8)
     error(EXIT_FAILURE, 0, "%s: the condition operand must be an "
-          "`uint8' type, but the given condition operand has a "
-          "`%s' type", __func__, gal_type_name(cond->type, 1));
+          "'uint8' type, but the given condition operand has a "
+          "'%s' type", __func__, gal_type_name(cond->type, 1));
 
   /* The dimension and sizes of the out and condition data sets must be the
      same. */
@@ -638,7 +798,7 @@ arithmetic_where(int flags, gal_data_t *out, gal_data_t *cond,
     case GAL_TYPE_FLOAT32:       WHERE_OUT_SET( float    );      break;
     case GAL_TYPE_FLOAT64:       WHERE_OUT_SET( double   );      break;
     default:
-      error(EXIT_FAILURE, 0, "%s: type code %d not recognized for the `out'",
+      error(EXIT_FAILURE, 0, "%s: type code %d not recognized for the 'out'",
             __func__, out->type);
     }
 
@@ -695,7 +855,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         t=max;                                                          \
         j=tprm->indexs[tind];                                           \
@@ -725,7 +885,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         t=min;                                                          \
         j=tprm->indexs[tind];                                           \
@@ -755,7 +915,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         j=tprm->indexs[tind];                                           \
                                                                         \
@@ -788,7 +948,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         sum=0.0f;                                                       \
         j=tprm->indexs[tind];                                           \
@@ -822,7 +982,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         sum=0.0f;                                                       \
         j=tprm->indexs[tind];                                           \
@@ -856,7 +1016,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         sum=sum2=0.0f;                                                  \
         j=tprm->indexs[tind];                                           \
@@ -896,11 +1056,11 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         j=tprm->indexs[tind];                                           \
                                                                         \
-        /* Loop over each array: `i' is input dataset's index. */       \
+        /* Loop over each array: 'i' is input dataset's index. */       \
         for(i=0;i<p->dnum;++i)                                          \
           {                                                             \
             /* Only integers and non-NaN floats: v==v is 1. */          \
@@ -932,6 +1092,51 @@ struct multioperandparams
 
 
 
+#define MULTIOPERAND_QUANTILE(TYPE) {                                   \
+    size_t n, j;                                                        \
+    gal_data_t *quantile;                                               \
+    TYPE *o=p->out->array;                                              \
+    TYPE *pixs=gal_pointer_allocate(p->list->type, p->dnum, 0,          \
+                                    __func__, "pixs");                  \
+    gal_data_t *cont=gal_data_alloc(pixs, p->list->type, 1, &p->dnum,   \
+                                    NULL, 0, -1, 1, NULL, NULL, NULL);  \
+                                                                        \
+    /* Go over all the pixels assigned to this thread. */               \
+    for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
+      {                                                                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
+        n=0;                                                            \
+        j=tprm->indexs[tind];                                           \
+                                                                        \
+        /* Read the necessay values from each input. */                 \
+        for(i=0;i<p->dnum;++i) pixs[n++]=a[i][j];                       \
+                                                                        \
+        /* If there are any elements, measure the  */                   \
+        if(n)                                                           \
+          {                                                             \
+            /* Calculate the quantile and put it in the output. */      \
+            quantile=gal_statistics_quantile(cont, p->p1, 1);           \
+            memcpy(&o[j], quantile->array,                              \
+                   gal_type_sizeof(p->list->type));                     \
+            gal_data_free(quantile);                                    \
+                                                                        \
+            /* Since we are doing sigma-clipping in place, the size, */ \
+            /* and flags need to be reset. */                           \
+            cont->flag=0;                                               \
+            cont->size=cont->dsize[0]=p->dnum;                          \
+          }                                                             \
+        else                                                            \
+          o[j]=b;                                                       \
+      }                                                                 \
+                                                                        \
+    /* Clean up. */                                                     \
+    gal_data_free(cont);                                                \
+  }
+
+
+
+
+
 #define MULTIOPERAND_SIGCLIP(TYPE) {                                    \
     size_t n, j;                                                        \
     gal_data_t *sclip;                                                  \
@@ -945,7 +1150,7 @@ struct multioperandparams
     /* Go over all the pixels assigned to this thread. */               \
     for(tind=0; tprm->indexs[tind] != GAL_BLANK_SIZE_T; ++tind)         \
       {                                                                 \
-        /* Initialize, `j' is desired pixel's index. */                 \
+        /* Initialize, 'j' is desired pixel's index. */                 \
         n=0;                                                            \
         j=tprm->indexs[tind];                                           \
                                                                         \
@@ -955,6 +1160,7 @@ struct multioperandparams
         /* If there are any elements, measure the  */                   \
         if(n)                                                           \
           {                                                             \
+            /* Calculate the sigma-clip and write it in. */             \
             sclip=gal_statistics_sigma_clip(cont, p->p1, p->p2, 1, 1);  \
             sarr=sclip->array;                                          \
             switch(p->operator)                                         \
@@ -968,6 +1174,7 @@ struct multioperandparams
                       "valid for sigma-clipping results", __func__,     \
                       p->operator);                                     \
               }                                                         \
+            gal_data_free(sclip);                                       \
                                                                         \
             /* Since we are doing sigma-clipping in place, the size, */ \
             /* and flags need to be reset. */                           \
@@ -997,7 +1204,7 @@ struct multioperandparams
     errno=0;                                                            \
     a=malloc(p->dnum*sizeof *a);                                        \
     if(a==NULL)                                                         \
-      error(EXIT_FAILURE, 0, "%s: %zu bytes for `a'",                   \
+      error(EXIT_FAILURE, 0, "%s: %zu bytes for 'a'",                   \
             "MULTIOPERAND_TYPE_SET", p->dnum*sizeof *a);                \
                                                                         \
     /* Fill in the array pointers and the blank value for this type. */ \
@@ -1036,6 +1243,10 @@ struct multioperandparams
         MULTIOPERAND_MEDIAN(TYPE, QSORT_F);                             \
         break;                                                          \
                                                                         \
+      case GAL_ARITHMETIC_OP_QUANTILE:                                  \
+        MULTIOPERAND_QUANTILE(TYPE);                                    \
+        break;                                                          \
+                                                                        \
       case GAL_ARITHMETIC_OP_SIGCLIP_STD:                               \
       case GAL_ARITHMETIC_OP_SIGCLIP_MEAN:                              \
       case GAL_ARITHMETIC_OP_SIGCLIP_MEDIAN:                            \
@@ -1113,7 +1324,7 @@ multioperand_on_thread(void *in_prm)
 
 /* The single operator in this function is assumed to be a linked list. The
    number of operators is determined from the fact that the last node in
-   the linked list must have a NULL pointer as its `next' element. */
+   the linked list must have a NULL pointer as its 'next' element. */
 static gal_data_t *
 arithmetic_multioperand(int operator, int flags, gal_data_t *list,
                         gal_data_t *params, size_t numthreads)
@@ -1125,7 +1336,7 @@ arithmetic_multioperand(int operator, int flags, gal_data_t *list,
   gal_data_t *out, *tmp, *ttmp;
 
 
-  /* For generality, `list' can be a NULL pointer, in that case, this
+  /* For generality, 'list' can be a NULL pointer, in that case, this
      function will return a NULL pointer and avoid further processing. */
   if(list==NULL) return NULL;
 
@@ -1144,6 +1355,17 @@ arithmetic_multioperand(int operator, int flags, gal_data_t *list,
       /* Write them */
       if(isnan(p1)) p1=((float *)(tmp->array))[0];
       else          p2=((float *)(tmp->array))[0];
+
+      /* Operator specific, parameter sanity checks. */
+      switch(operator)
+        {
+        case GAL_ARITHMETIC_OP_QUANTILE:
+          if(p1<0 || p1>1)
+            error(EXIT_FAILURE, 0, "%s: the parameter given to the 'quantile' "
+                  "operator must be between (and including) 0 and 1. The "
+                  "given value is: %g", __func__, p1);
+          break;
+        }
     }
 
 
@@ -1178,6 +1400,7 @@ arithmetic_multioperand(int operator, int flags, gal_data_t *list,
     case GAL_ARITHMETIC_OP_MEAN:           otype=GAL_TYPE_FLOAT32; break;
     case GAL_ARITHMETIC_OP_STD:            otype=GAL_TYPE_FLOAT32; break;
     case GAL_ARITHMETIC_OP_MEDIAN:         otype=GAL_TYPE_FLOAT32; break;
+    case GAL_ARITHMETIC_OP_QUANTILE:       otype=list->type;       break;
     case GAL_ARITHMETIC_OP_SIGCLIP_STD:    otype=GAL_TYPE_FLOAT32; break;
     case GAL_ARITHMETIC_OP_SIGCLIP_MEAN:   otype=GAL_TYPE_FLOAT32; break;
     case GAL_ARITHMETIC_OP_SIGCLIP_MEDIAN: otype=GAL_TYPE_FLOAT32; break;
@@ -1261,7 +1484,7 @@ arithmetic_multioperand(int operator, int flags, gal_data_t *list,
    don't need to be checked (the floating point standard will do the job
    for us). It is also not necessary to check blanks in bitwise operators,
    but bitwise operators have their own macro
-   (`BINARY_OP_INCR_OT_RT_LT_SET') which doesn' use `checkblanks'.*/
+   ('BINARY_OP_INCR_OT_RT_LT_SET') which doesn' use 'checkblanks'.*/
 int
 gal_arithmetic_binary_checkblank(gal_data_t *l, gal_data_t *r)
 {
@@ -1299,7 +1522,7 @@ arithmetic_binary_out_type(int operator, gal_data_t *l, gal_data_t *r)
 static gal_data_t *
 arithmetic_binary(int operator, int flags, gal_data_t *l, gal_data_t *r)
 {
-  /* Read the variable arguments. `lo' and `ro' keep the original data, in
+  /* Read the variable arguments. 'lo' and 'ro' keep the original data, in
      case their type isn't built (based on configure options are configure
      time). */
   int32_t otype;
@@ -1317,10 +1540,10 @@ arithmetic_binary(int operator, int flags, gal_data_t *l, gal_data_t *r)
 
 
   /* Set the output type. For the comparison operators, the output type is
-     either 0 or 1, so we will set the output type to `unsigned char' for
+     either 0 or 1, so we will set the output type to 'unsigned char' for
      efficient memory and CPU usage. Since the number of operators without
-     a fixed output type (like the conditionals) is less, by `default' we
-     will set the output type to `unsigned char', and if any of the other
+     a fixed output type (like the conditionals) is less, by 'default' we
+     will set the output type to 'unsigned char', and if any of the other
      operatrs are given, it will be chosen based on the input types.*/
   otype=arithmetic_binary_out_type(operator, l, r);
 
@@ -1341,8 +1564,8 @@ arithmetic_binary(int operator, int flags, gal_data_t *l, gal_data_t *r)
 
 
   /* If the output pointer was not set above for any of the possible
-     reasons, allocate it. For `mmapsize', note that since its `size_t', it
-     will always be positive. The `-1' that is recommended to give when you
+     reasons, allocate it. For 'mmapsize', note that since its 'size_t', it
+     will always be positive. The '-1' that is recommended to give when you
      want the value in RAM is actually the largest possible memory
      location. So we just have to choose the smaller minmapsize of the two
      to decide if the output array should be in RAM or not. */
@@ -1497,8 +1720,8 @@ arithmetic_binary_function_flt(int operator, int flags, gal_data_t *l,
 
 
   /* If the output pointer was not set for any reason, allocate it. For
-     `mmapsize', note that since its `size_t', it will always be
-     Positive. The `-1' that is recommended to give when you want the value
+     'mmapsize', note that since its 'size_t', it will always be
+     Positive. The '-1' that is recommended to give when you want the value
      in RAM is actually the largest possible memory location. So we just
      have to choose the smaller minmapsize of the two to decide if the
      output array should be in RAM or not. */
@@ -1521,10 +1744,10 @@ arithmetic_binary_function_flt(int operator, int flags, gal_data_t *l,
 
 
   /* Clean up. Note that if the input arrays can be freed, and any of right
-     or left arrays needed conversion, `BINFUNC_CONVERT_TO_COMPILED_TYPE'
-     has already freed the input arrays, and we only have `r' and `l'
+     or left arrays needed conversion, 'BINFUNC_CONVERT_TO_COMPILED_TYPE'
+     has already freed the input arrays, and we only have 'r' and 'l'
      allocated in any case. Alternatively, when the inputs shouldn't be
-     freed, the only allocated spaces are the `r' and `l' arrays if their
+     freed, the only allocated spaces are the 'r' and 'l' arrays if their
      types weren't compiled for binary operations, we can tell this from
      the pointers: if they are different from the original pointers, they
      were allocated. */
@@ -1591,6 +1814,16 @@ gal_arithmetic_set_operator(char *string, size_t *num_operands)
   else if (!strcmp(string, "log10"))
     { op=GAL_ARITHMETIC_OP_LOG10;             *num_operands=1;  }
 
+  /* Units conversion functions */
+  else if (!strcmp(string, "ra-to-degree"))
+    { op=GAL_ARITHMETIC_OP_RA_TO_DEGREE;   *num_operands=1;  }
+  else if (!strcmp(string, "dec-to-degree"))
+    { op=GAL_ARITHMETIC_OP_DEC_TO_DEGREE;  *num_operands=1;  }
+  else if (!strcmp(string, "degree-to-ra"))
+    { op=GAL_ARITHMETIC_OP_DEGREE_TO_DEC;  *num_operands=1;  }
+  else if (!strcmp(string, "degree-to-dec"))
+    { op=GAL_ARITHMETIC_OP_DEGREE_TO_DEC;  *num_operands=1;  }
+
   /* Statistical/higher-level operators. */
   else if (!strcmp(string, "minvalue"))
     { op=GAL_ARITHMETIC_OP_MINVAL;            *num_operands=1;  }
@@ -1620,6 +1853,8 @@ gal_arithmetic_set_operator(char *string, size_t *num_operands)
     { op=GAL_ARITHMETIC_OP_STD;               *num_operands=-1; }
   else if (!strcmp(string, "median"))
     { op=GAL_ARITHMETIC_OP_MEDIAN;            *num_operands=-1; }
+  else if (!strcmp(string, "quantile"))
+    { op=GAL_ARITHMETIC_OP_QUANTILE;          *num_operands=-1; }
   else if (!strcmp(string, "sigclip-number"))
     { op=GAL_ARITHMETIC_OP_SIGCLIP_NUMBER;    *num_operands=-1; }
   else if (!strcmp(string, "sigclip-mean"))
@@ -1629,6 +1864,10 @@ gal_arithmetic_set_operator(char *string, size_t *num_operands)
   else if (!strcmp(string, "sigclip-std"))
     { op=GAL_ARITHMETIC_OP_SIGCLIP_STD;       *num_operands=-1; }
 
+  /* The size operator */
+  else if (!strcmp(string, "size"))
+    { op=GAL_ARITHMETIC_OP_SIZE;              *num_operands=2;  }
+
   /* Conditional operators. */
   else if (!strcmp(string, "lt" ))
     { op=GAL_ARITHMETIC_OP_LT;                *num_operands=2;  }
@@ -1735,6 +1974,11 @@ gal_arithmetic_operator_string(int operator)
     case GAL_ARITHMETIC_OP_LOG:             return "log";
     case GAL_ARITHMETIC_OP_LOG10:           return "log10";
 
+    case GAL_ARITHMETIC_OP_RA_TO_DEGREE:    return "ra-to-degree";
+    case GAL_ARITHMETIC_OP_DEC_TO_DEGREE:   return "dec-to-degree";
+    case GAL_ARITHMETIC_OP_DEGREE_TO_RA:    return "degree-to-ra";
+    case GAL_ARITHMETIC_OP_DEGREE_TO_DEC:   return "degree-to-dec";
+
     case GAL_ARITHMETIC_OP_MINVAL:          return "minvalue";
     case GAL_ARITHMETIC_OP_MAXVAL:          return "maxvalue";
     case GAL_ARITHMETIC_OP_NUMBERVAL:       return "numbervalue";
@@ -1750,11 +1994,14 @@ gal_arithmetic_operator_string(int operator)
     case GAL_ARITHMETIC_OP_MEAN:            return "mean";
     case GAL_ARITHMETIC_OP_STD:             return "std";
     case GAL_ARITHMETIC_OP_MEDIAN:          return "median";
+    case GAL_ARITHMETIC_OP_QUANTILE:        return "quantile";
     case GAL_ARITHMETIC_OP_SIGCLIP_NUMBER:  return "sigclip-number";
     case GAL_ARITHMETIC_OP_SIGCLIP_MEDIAN:  return "sigclip-median";
     case GAL_ARITHMETIC_OP_SIGCLIP_MEAN:    return "sigclip-mean";
     case GAL_ARITHMETIC_OP_SIGCLIP_STD:     return "sigclip-number";
 
+    case GAL_ARITHMETIC_OP_SIZE:            return "size";
+
     case GAL_ARITHMETIC_OP_TO_UINT8:        return "uchar";
     case GAL_ARITHMETIC_OP_TO_INT8:         return "char";
     case GAL_ARITHMETIC_OP_TO_UINT16:       return "ushort";
@@ -1830,6 +2077,10 @@ gal_arithmetic(int operator, size_t numthreads, int flags, ...)
     case GAL_ARITHMETIC_OP_SQRT:
     case GAL_ARITHMETIC_OP_LOG:
     case GAL_ARITHMETIC_OP_LOG10:
+    case GAL_ARITHMETIC_OP_RA_TO_DEGREE:
+    case GAL_ARITHMETIC_OP_DEC_TO_DEGREE:
+    case GAL_ARITHMETIC_OP_DEGREE_TO_RA:
+    case GAL_ARITHMETIC_OP_DEGREE_TO_DEC:
       d1 = va_arg(va, gal_data_t *);
       out=arithmetic_unary_function(operator, flags, d1);
       break;
@@ -1860,6 +2111,7 @@ gal_arithmetic(int operator, size_t numthreads, int flags, ...)
     case GAL_ARITHMETIC_OP_MEAN:
     case GAL_ARITHMETIC_OP_STD:
     case GAL_ARITHMETIC_OP_MEDIAN:
+    case GAL_ARITHMETIC_OP_QUANTILE:
     case GAL_ARITHMETIC_OP_SIGCLIP_STD:
     case GAL_ARITHMETIC_OP_SIGCLIP_MEAN:
     case GAL_ARITHMETIC_OP_SIGCLIP_MEDIAN:
@@ -1911,10 +2163,16 @@ gal_arithmetic(int operator, size_t numthreads, int flags, ...)
       out=arithmetic_change_type(d1, operator, flags);
       break;
 
+    /* Size operator */
+    case GAL_ARITHMETIC_OP_SIZE:
+      d1 = va_arg(va, gal_data_t *);
+      d2 = va_arg(va, gal_data_t *);
+      out=arithmetic_size(operator, flags, d1, d2);
+      break;
 
     /* When the operator is not recognized. */
     default:
-      error(EXIT_FAILURE, 0, "%s: the argument \"%d\" could not be "
+      error(EXIT_FAILURE, 0, "%s: the argument '%d' could not be "
             "interpretted as an operator", __func__, operator);
     }
 
