@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017-2019, Free Software Foundation, Inc.
+Copyright (C) 2017-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -41,7 +41,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 
 /* Write the blank value of the type into an already allocate space. Note
-   that for STRINGS, pointer should actually be `char **'. */
+   that for STRINGS, pointer should actually be 'char **'. */
 void
 gal_blank_write(void *ptr, uint8_t type)
 {
@@ -114,8 +114,27 @@ gal_blank_initialize(gal_data_t *input)
 
 
 
+/* Initialize an array to the given type's blank values.*/
+void
+gal_blank_initialize_array(void *array, size_t size, uint8_t type)
+{
+  size_t i, w=gal_type_sizeof(type);
+  void *b=gal_blank_alloc_write(type);
+
+  /* Set all the elements to blank. */
+  for(i=0;i<size;++i)
+    memcpy(gal_pointer_increment(array, i, type), b, w);
+
+  /* Clean up. */
+  free(b);
+}
+
+
+
+
+
 /* Print the blank value as a string. For the integer types, we'll use the
-   PRIxNN keywords of `inttypes.h' (which is imported into Gnuastro from
+   PRIxNN keywords of 'inttypes.h' (which is imported into Gnuastro from
    Gnulib, so we don't necessarily rely on the host system having it). */
 char *
 gal_blank_as_string(uint8_t type, int width)
@@ -345,13 +364,13 @@ gal_blank_is(void *pointer, uint8_t type)
 
 /* Return 1 if the dataset has a blank value and zero if it doesn't. Before
    checking the dataset, this function will look at its flags. If the
-   `GAL_DATA_FLAG_HASBLANK' or `GAL_DATA_FLAG_DONT_CHECK_ZERO' bits of
-   `input->flag' are set to 1, this function will not do any check and will
+   'GAL_DATA_FLAG_HASBLANK' or 'GAL_DATA_FLAG_DONT_CHECK_ZERO' bits of
+   'input->flag' are set to 1, this function will not do any check and will
    just use the information in the flags.
 
    If you want to re-check a dataset which has non-zero flags, then
    explicitly set the appropriate flag to zero before calling this
-   function. When there are no other flags, you can just set `input->flags'
+   function. When there are no other flags, you can just set 'input->flags'
    to zero, otherwise you can use this expression:
 
        input->flags &= ~ (GAL_DATA_FLAG_HASBLANK | GAL_DATA_FLAG_USE_ZERO);
@@ -515,8 +534,8 @@ gal_blank_flag(gal_data_t *input)
       /* Allocate a non-cleared output array, we are going to parse the
          input and fill in each element. */
       out=gal_data_alloc(NULL, GAL_TYPE_UINT8, input->ndim, input->dsize,
-                         input->wcs, 0, input->minmapsize, NULL, "bool",
-                         NULL);
+                         input->wcs, 0, input->minmapsize, input->quietmmap,
+                         NULL, "bool", NULL);
 
       /* Set the pointers for easy looping. */
       of=(o=out->array)+input->size;
@@ -557,7 +576,8 @@ gal_blank_flag(gal_data_t *input)
   else
     /* Allocate a CLEAR data structure (all zeros). */
     out=gal_data_alloc(NULL, GAL_TYPE_UINT8, input->ndim, input->dsize,
-                       input->wcs, 1, input->minmapsize, NULL, "bool", NULL);
+                       input->wcs, 1, input->minmapsize, input->quietmmap,
+                       NULL, "bool", NULL);
 
   /* Return */
   return out;
@@ -582,12 +602,12 @@ gal_blank_flag_apply(gal_data_t *input, gal_data_t *flag)
 
   /* Sanity check. */
   if(flag->type!=GAL_TYPE_UINT8)
-    error(EXIT_FAILURE, 0, "%s: the `flag' argument has a `%s' type, it "
+    error(EXIT_FAILURE, 0, "%s: the 'flag' argument has a '%s' type, it "
           "must have an unsigned 8-bit type", __func__,
           gal_type_name(flag->type, 1));
   if(gal_dimension_is_different(input, flag))
-    error(EXIT_FAILURE, 0, "%s: the `flag' argument doesn't have the same "
-          "size as the `input' argument", __func__);
+    error(EXIT_FAILURE, 0, "%s: the 'flag' argument doesn't have the same "
+          "size as the 'input' argument", __func__);
 
   /* Write the blank values. */
   switch(input->type)
@@ -640,9 +660,9 @@ gal_blank_flag_apply(gal_data_t *input, gal_data_t *flag)
 
 
 /* Remove blank elements from a dataset, convert it to a 1D dataset and
-   adjust the size properly. In practice this function doesn't `realloc'
+   adjust the size properly. In practice this function doesn't 'realloc'
    the input array, all it does is to shift the blank eleemnts to the end
-   and adjust the size elements of the `gal_data_t'. */
+   and adjust the size elements of the 'gal_data_t'. */
 #define BLANK_REMOVE(IT) {                                              \
     IT b, *a=input->array, *af=a+input->size, *o=input->array;          \
     gal_blank_write(&b, input->type);                                   \
@@ -693,3 +713,22 @@ gal_blank_remove(gal_data_t *input)
   input->flag |= GAL_DATA_FLAG_BLANK_CH;
   input->flag &= ~GAL_DATA_FLAG_HASBLANK;
 }
+
+
+
+
+
+/* Similar to 'gal_blank_remove', but also reallocates/frees the extra
+   space. */
+void
+gal_blank_remove_realloc(gal_data_t *input)
+{
+  /* Remove the blanks and fix the size of the dataset. */
+  gal_blank_remove(input);
+
+  /* Run realloc to shrink the allocated space. */
+  input->array=realloc(input->array,
+                       input->size*gal_type_sizeof(input->type));
+  if(input->array==NULL)
+    error(EXIT_FAILURE, 0, "%s: couldn't reallocate memory", __func__);
+}
