@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -52,6 +52,9 @@ gal_list_str_add(gal_list_str_t **list, char *value,
 {
   gal_list_str_t *newnode;
 
+  /* If the value is a NULL pointer, don't add to the list. */
+  if(value==NULL) return;
+
   errno=0;
   newnode=malloc(sizeof *newnode);
   if(newnode==NULL)
@@ -1179,11 +1182,11 @@ gal_list_dosizet_pop_smallest(gal_list_dosizet_t **largest,
     }
   else
     {
-      /* If `smallest' is NULL, `largest' should also be NULL. */
+      /* If 'smallest' is NULL, 'largest' should also be NULL. */
       if(*largest)
-        error(EXIT_FAILURE, 0, "%s: `largest' and `smallest' pointers must "
+        error(EXIT_FAILURE, 0, "%s: 'largest' and 'smallest' pointers must "
               "both be non-NULL or both be NULL. However, in this call, "
-              "`smallest' was NULL while `largest' isn't NULL", __func__);
+              "'smallest' was NULL while 'largest' isn't NULL", __func__);
       value=GAL_BLANK_SIZE_T;
       *tosort=NAN;
     }
@@ -1286,7 +1289,7 @@ gal_list_data_add(gal_data_t **list, gal_data_t *newnode)
       toadd=tmp;
     }
   else
-    /* Its not a list, so just set it to `toadd'. */
+    /* Its not a list, so just set it to 'toadd'. */
     toadd=newnode;
 
 
