@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2019, Free Software Foundation, Inc.
+Copyright (C) 2016-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -66,7 +66,7 @@ enum txt_formats_code
 
 
 
-/* Return one of the `txt_line_stat' constant values. */
+/* Return one of the 'txt_line_stat' constant values. */
 int
 gal_txt_line_stat(char *line)
 {
@@ -93,8 +93,8 @@ gal_txt_line_stat(char *line)
 
 /* Remove the spaces around the values, and if the final/trimmed string has
    no length, return NULL. */
-static char *
-txt_trim_space(char *str)
+char *
+gal_txt_trim_space(char *str)
 {
   char *end;
 
@@ -104,11 +104,10 @@ txt_trim_space(char *str)
   /* Remove the spaces before the start of the string. */
   while(isspace(*str)) ++str;
 
-  /* If there was nothing in the string, then just return the ending `\0'
-     character. */
+  /* If there was nothing in the string, return NULL. */
   if(*str=='\0') return NULL;
 
-  /* Remove the spaces at the end, and write a possibly new `\0'. */
+  /* Remove the spaces at the end, and write a possibly new '\0'. */
   end = str + strlen(str) - 1;
   while(end>str && isspace(*end)) --end;
   *(end+1)='\0';
@@ -122,7 +121,7 @@ txt_trim_space(char *str)
 
 
 /* Each information comment should have a format like this (replace
-   `Column' with `Image' for 2D arrays):
+   'Column' with 'Image' for 2D arrays):
 
       # Column N: NAME [UNITS, TYPE, BLANK] COMMENT
 
@@ -132,17 +131,17 @@ txt_trim_space(char *str)
   set. But if there are comments, then the brackets themselves are required
   to separate the name from the comments.
 
-  Any white space characters before or after the delimiters (`:', `[', `]',
-  `,') is ignored, but spaces within the values are kept. For example, in
-  the two following lines, NAME will be set to `col name' (even though
+  Any white space characters before or after the delimiters (':', '[', ']',
+  ',') is ignored, but spaces within the values are kept. For example, in
+  the two following lines, NAME will be set to 'col name' (even though
   there are extra spaces in the second line, The column unit will be
-  set to `col unit'.
+  set to 'col unit'.
 
       # Column 2: col name
       # Column 2 :  col name     [ col unit, type ] Column comments.
 
   When the column type is a string, the number of characters in the string
-  is also necessary, for example `str10'. Without an integer attached, the
+  is also necessary, for example 'str10'. Without an integer attached, the
   line will be ignored.
 
   In the case of an error or mis-match, the line will be ignored.
@@ -153,20 +152,33 @@ txt_trim_space(char *str)
   be before column 7.
 */
 static void
-txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
+txt_info_from_comment(char *in_line, gal_data_t **datall, char *comm_start,
+                      int inplace)
 {
-  char *tailptr;
   gal_data_t *tmp;
   int index, strw=0;
+  char *line, *aline, *tailptr;
   size_t len=strlen(comm_start);
   int type=GAL_TYPE_FLOAT64;                     /* Default type. */
   char *number=NULL, *name=NULL, *comment=NULL;
   char *inbrackets=NULL, *unit=NULL, *typestr=NULL, *blank=NULL;
 
+  /* Make a copy of the input line if 'inplace==0'. */
+  if(inplace) line=aline=in_line;
+  else
+    {
+      /* Because the 'line' pointer will change, we need a pointer to the
+         start of the originally allocated lines. This is the purpose of
+         'aline' (allocated-line). */
+      gal_checkset_allocate_copy(in_line, &aline);
+      line=aline;
+    }
+
+
   /* Only read this comment line if it follows the convention: */
   if( !strncmp(line, comm_start, len) )
     {
-      /* Set `name', `inbrackets', and `comment' in the first pass through
+      /* Set 'name', 'inbrackets', and 'comment' in the first pass through
          the line. */
       number=line+len;
       while(*line!='\0')
@@ -200,11 +212,11 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
       if(*tailptr!='\0' || index<=0) return;
 
 
-      /* If there was no name (the line is just `# Column N:'), then ignore
+      /* If there was no name (the line is just '# Column N:'), then ignore
          the line. Relying on the column count from the first line is more
          robust and less prone to human error, for example typing a number
          larger than the total number of columns.  */
-      name=txt_trim_space(name);
+      name=gal_txt_trim_space(name);
       if(name==NULL) return;
 
 
@@ -231,8 +243,8 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
         }
 
 
-      /* If `typestr' was given, then check if this is a standard type. If
-         `typestr' wasn't specified, then the default double type code will
+      /* If 'typestr' was given, then check if this is a standard type. If
+         'typestr' wasn't specified, then the default double type code will
          be used (see the variable definitions above). If the given type
          isn't a standard type then ignore the line. Just note that if we
          are dealing with the string type, we have to pull out the number
@@ -240,7 +252,7 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
          the line. */
       if(typestr && *typestr!='\0')
         {
-          typestr=txt_trim_space(typestr);
+          typestr=gal_txt_trim_space(typestr);
           if( !strncmp(typestr, "str", 3) )
             {
               type=GAL_TYPE_STRING;
@@ -258,11 +270,12 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
       /* Add this column's information into the columns linked list. We
          will define the data structur's array to have zero dimensions (no
          array) by default. If there is a blank value its value will be put
-         into the array by `gal_table_read_blank'. To keep the name, unit,
+         into the array by 'gal_table_read_blank'. To keep the name, unit,
          and comment strings, trim the white space before and after each
          before using them here.  */
-      gal_list_data_add_alloc(datall, NULL, type, 0, NULL, NULL, 0, -1, name,
-                              txt_trim_space(unit), txt_trim_space(comment) );
+      gal_list_data_add_alloc(datall, NULL, type, 0, NULL, NULL, 0, -1, 1,
+                              name, gal_txt_trim_space(unit),
+                              gal_txt_trim_space(comment) );
 
 
       /* Put the number of this column into the status variable of the data
@@ -274,8 +287,11 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
 
       /* Write the blank value into the array. Note that this is not the
          final column, we are just collecting information now. */
-      gal_tableintern_read_blank(*datall, txt_trim_space(blank));
+      gal_tableintern_read_blank(*datall, gal_txt_trim_space(blank));
     }
+
+  /* Clean up. */
+  if(in_line!=aline) free(aline);
 }
 
 
@@ -303,7 +319,7 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
   else
     {
       gal_checkset_allocate_copy(in_line, &line);
-      aline=line; /* We are going to change `line' during this function. */
+      aline=line; /* We are going to change 'line' during this function. */
     }
   end=line+strlen(line);
 
@@ -340,7 +356,7 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
 
 
       /* If there is information for this column, then check if it is a
-         string, and if so, don't use `strtok_r' (because it might have
+         string, and if so, don't use 'strtok_r' (because it might have
          delimiters). So manually go ahead in the line till you get to the
          start of the string, then increment the line until the end of the
          space set for the strings. */
@@ -356,9 +372,9 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
 
               /* If we haven't reached the end of the line, then set a NULL
                  character where the string ends, so we can use the
-                 token. VERY IMPORTANT: this should not be `<=end'. If the
+                 token. VERY IMPORTANT: this should not be '<=end'. If the
                  given width is larger than line, there is no problem, the
-                 `\0' of the line will also be used to end this last
+                 '\0' of the line will also be used to end this last
                  column.*/
               if(line<end)
                 {
@@ -385,28 +401,28 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
              no information, then set its status value to the column
              number. So, for a table, this should be done on every
              column. But for an image, this should only be done once (when
-             `datall' has not been defined yet, for example in the column
+             'datall' has not been defined yet, for example in the column
              information). */
           if( *datall==NULL || format==TXT_FORMAT_TABLE )
             {
               gal_list_data_add_alloc(datall, NULL, GAL_TYPE_FLOAT64, 0,
-                                      NULL, NULL, 0, -1, NULL, NULL, NULL);
+                                      NULL, NULL, 0, -1, 1, NULL, NULL, NULL);
               (*datall)->status=n;
             }
         }
     }
 
 
-  /* When looking at a text table, `n' is the number of columns (elements
+  /* When looking at a text table, 'n' is the number of columns (elements
      in the linked list). But when looking at an image, it is the size of
      the second dimension. To unify things from this step forwards, we will
-     thus keep the value of `n' until this point in another variable (that
-     will be returned finally), and for an image, change `n' to 1. This is
+     thus keep the value of 'n' until this point in another variable (that
+     will be returned finally), and for an image, change 'n' to 1. This is
      necsesary in case the user has for example given two column
      information comments on an image plain text file.
 
-     Note that `n' counts from 1, so the total number of tokens is one less
-     than `n'.*/
+     Note that 'n' counts from 1, so the total number of tokens is one less
+     than 'n'.*/
   numtokens=n-1;
   if(format==TXT_FORMAT_IMAGE) n=1;
 
@@ -425,7 +441,7 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
               /* This column has to be removed/freed. But we have to make
                  some corrections before freeing it:
 
-                  - When `prev==NULL', then we still haven't got to the
+                  - When 'prev==NULL', then we still haven't got to the
                     first valid element yet and must free this one, but if
                     we do that, then the main pointer to the start of the
                     list will be lost (we will loose all connections with
@@ -433,7 +449,7 @@ txt_info_from_first_row(char *in_line, gal_data_t **datall, int format,
                     that to the next element.
 
                   - When there actually was a previous element
-                    (`prev!=NULL'), then we must correct it's next
+                    ('prev!=NULL'), then we must correct it's next
                     pointer. Otherwise we will break up the chain.*/
               if(prev) prev->next=col->next; else *datall=col->next;
               tmp=col->next;
@@ -493,14 +509,14 @@ txt_infoll_to_array(gal_data_t *datall, size_t *numdata)
           /* Pop the top element. */
           data=gal_list_data_pop(&datall);
 
-          /* The `status' value is the number of the column (counting from
+          /* The 'status' value is the number of the column (counting from
              1, not 0). */
           ind=data->status-1;
 
-          /* Put all the information from `data' into the respective part
+          /* Put all the information from 'data' into the respective part
              of the array. About the pointers, instead of having to
              allocate them again, we will just set them to NULL so
-             `gal_data_free' doesn't remove them.*/
+             'gal_data_free' doesn't remove them.*/
           dataarr[ind].name       = data->name;    data->name=NULL;
           dataarr[ind].unit       = data->unit;    data->unit=NULL;
           dataarr[ind].array      = data->array;   data->array=NULL;
@@ -539,7 +555,7 @@ txt_get_info_line(char *line, gal_data_t **datall, char *comm_start,
     {
       /* Line is a comment, see if it has formatted information. */
     case GAL_TXT_LINESTAT_COMMENT:
-      txt_info_from_comment(line, datall, comm_start);
+      txt_info_from_comment(line, datall, comm_start, inplace);
       break;
 
       /* Line is actual data, use it to fill in the gaps.  */
@@ -573,12 +589,12 @@ txt_get_info(char *filename, gal_list_str_t *lines, int format,
   gal_data_t *datall=NULL;
   int test, firstlinedone=0;
   char *line, *format_err="empty", *comm_start;
-  size_t linelen=10; /* `linelen' will be increased by `getline'. */
+  size_t linelen=10; /* 'linelen' will be increased by 'getline'. */
 
-  /* `filename' and `lines' cannot both be non-NULL. */
+  /* 'filename' and 'lines' cannot both be non-NULL. */
   test = (filename!=NULL) + (lines!=NULL);
   if( test!=1 )
-    error(EXIT_FAILURE, 0, "%s: one of the `filename' and `lines' "
+    error(EXIT_FAILURE, 0, "%s: one of the 'filename' and 'lines' "
           "arguments must be NULL, but they are both %s", __func__,
           test==2 ? "non-NULL" : "NULL");
 
@@ -592,7 +608,7 @@ txt_get_info(char *filename, gal_list_str_t *lines, int format,
             __func__, format);
     }
 
-  /* Initialize the first `dsize' element. */
+  /* Initialize the first 'dsize' element. */
   dsize[0]=0;
 
   /* Parse the file or go over the lines. */
@@ -603,12 +619,12 @@ txt_get_info(char *filename, gal_list_str_t *lines, int format,
       fp=fopen(filename, "r");
       if(fp==NULL)
         error(EXIT_FAILURE, errno, "%s: couldn't open to read as a plain "
-              "text %s (from Gnuastro's `%s')", filename, format_err,
+              "text %s (from Gnuastro's '%s')", filename, format_err,
               __func__);
 
 
       /* Allocate the space necessary to keep each line as we parse
-         it. Note that `getline' is going to later `realloc' this space to
+         it. Note that 'getline' is going to later 'realloc' this space to
          fit the line length. */
       errno=0;
       line=malloc(linelen*sizeof *line);
@@ -715,7 +731,7 @@ txt_read_token(gal_data_t *data, gal_data_t *info, char *token,
   switch(data->type)
     {
     case GAL_TYPE_STRING:
-      gal_checkset_allocate_copy(txt_trim_space(token), &str[i]);
+      gal_checkset_allocate_copy(gal_txt_trim_space(token), &str[i]);
       if( (strb=info->array) && !strcmp( *strb, str[i] ) )
         {
           free(str[i]);
@@ -773,7 +789,7 @@ txt_read_token(gal_data_t *data, gal_data_t *info, char *token,
 
       /* For the blank value of floating point types, we need to make
          sure it isn't a NaN, because a NaN value will fail on any
-         condition check (even `=='). If it isn't NaN, then we can
+         condition check (even '=='). If it isn't NaN, then we can
          compare the values. */
     case GAL_TYPE_FLOAT32:
       f[i]=strtod(token, &tailptr);
@@ -797,7 +813,7 @@ txt_read_token(gal_data_t *data, gal_data_t *info, char *token,
   /* If a number couldn't be read properly, then report an error. */
   if(data->type!=GAL_TYPE_STRING && *tailptr!='\0')
     error_at_line(EXIT_FAILURE, 0, filename, lineno, "column %zu "
-                  "(`%s') couldn't be read as a `%s' number",
+                  "('%s') couldn't be read as a '%s' number",
                   colnum, token, gal_type_name(data->type, 1) );
 }
 
@@ -808,7 +824,7 @@ txt_read_token(gal_data_t *data, gal_data_t *info, char *token,
 static void
 txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
          gal_data_t *out, size_t rowind, char *filename, size_t lineno,
-         int inplace)
+         int inplace, int format)
 {
   size_t i, n=0;
   gal_data_t *data;
@@ -820,15 +836,15 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
   else
     {
       gal_checkset_allocate_copy(in_line, &line);
-      aline=line; /* We are going to change `line' during this function. */
+      aline=line; /* We are going to change 'line' during this function. */
     }
   end=line+strlen(line);
 
-  /* See explanations in `txt_info_from_first_row'. */
+  /* See explanations in 'txt_info_from_first_row'. */
   if( end>line+2 && *(end-2)==13 ) *(end-2)='\0';
   else if( *(end-1)=='\n' )        *(end-1)='\0';
 
-  /* Start parsing the line. Note that `n' and `maxcolnum' start from
+  /* Start parsing the line. Note that 'n' and 'maxcolnum' start from
      one. */
   while(++n)
     {
@@ -838,8 +854,10 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
       if(n>maxcolnum) break;
 
       /* Set the pointer to the start of this token/column. See
-         explanations in `txt_info_from_first_row'. */
-      if( info[n-1].type == GAL_TYPE_STRING )
+         explanations in 'txt_info_from_first_row'. Note that an image has
+         a single 'info' element for the whole array, while a table has one
+         for each column. */
+      if( info[format==TXT_FORMAT_TABLE ? n-1 : 0].type == GAL_TYPE_STRING )
         {
           /* Remove any delimiters and stop at the first non-delimiter. If
              we have reached the end of the line then its an error, because
@@ -854,7 +872,7 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
         }
       else
         {
-          /* If we have reached the end of the line, then `strtok_r' will
+          /* If we have reached the end of the line, then 'strtok_r' will
              return a NULL pointer. */
           tokens[n]=strtok_r(n==1?line:NULL, GAL_TXT_DELIMITERS, &line);
           if(tokens[n]==NULL) {notenoughcols=1; break;}
@@ -866,7 +884,7 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
     error_at_line(EXIT_FAILURE, 0, filename, lineno, "not enough columns in "
                   "this line. Previous (uncommented) lines in this file had "
                   "%zu columns, but this line has %zu columns", maxcolnum,
-                  n-1); /* This must be `n-1' (since n starts from 1). */
+                  n-1); /* This must be 'n-1' (since n starts from 1). */
 
   /* For a sanity check:
   printf("row: %zu: ", rowind+1);
@@ -876,7 +894,7 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
 
   /* Read the desired tokens into the columns that need them. Note that
      when a blank value is defined for the column, the column's array
-     pointer (`info[col->status-1]') is not NULL and points to the blank
+     pointer ('info[col->status-1]') is not NULL and points to the blank
      value. For strings, this will actually be a string. */
   switch(out->ndim)
     {
@@ -908,7 +926,7 @@ txt_fill(char *in_line, char **tokens, size_t maxcolnum, gal_data_t *info,
 static gal_data_t *
 txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
          gal_data_t *info, gal_list_sizet_t *indexll, size_t minmapsize,
-         int format)
+         int quietmmap, int format)
 {
   FILE *fp;
   int test;
@@ -918,22 +936,22 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
   gal_data_t *out=NULL;
   gal_list_sizet_t *ind;
   size_t one=1, maxcolnum=0, rowind=0, lineno=0, ndim;
-  size_t linelen=10;        /* `linelen' will be increased by `getline'. */
+  size_t linelen=10;        /* 'linelen' will be increased by 'getline'. */
 
-  /* `filename' and `lines' cannot both be non-NULL. */
+  /* 'filename' and 'lines' cannot both be non-NULL. */
   test = (filename!=NULL) + (lines!=NULL);
   if( test!=1 )
-    error(EXIT_FAILURE, 0, "%s: one of the `filename' and `lines' "
+    error(EXIT_FAILURE, 0, "%s: one of the 'filename' and 'lines' "
           "arguments must be NULL, but they are both %s", __func__,
           test==2 ? "non-NULL" : "NULL");
 
   /* Allocate the space necessary to keep a copy of each line as we parse
-     it. Note that `getline' is going to later `realloc' this space to fit
+     it. Note that 'getline' is going to later 'realloc' this space to fit
      the line length. */
   errno=0;
   line=malloc(linelen*sizeof *line);
   if(line==NULL)
-    error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for `line'",
+    error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for 'line'",
           __func__, linelen*sizeof *line);
 
   /* Allocate all the desired columns for output. We will be reading the
@@ -953,8 +971,8 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
           maxcolnum = maxcolnum>ind->v+1 ? maxcolnum : ind->v+1;
           gal_list_data_add_alloc(&out, NULL, info[ind->v].type, ndim,
                                   dsize[0]?dsize:&one, NULL, 0, minmapsize,
-                                  info[ind->v].name, info[ind->v].unit,
-                                  info[ind->v].comment);
+                                  quietmmap, info[ind->v].name,
+                                  info[ind->v].unit, info[ind->v].comment);
           out->disp_width=info[ind->v].disp_width;
           out->status=ind->v+1;
 
@@ -975,12 +993,12 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
     case TXT_FORMAT_IMAGE:
       if(info->next)
         error(EXIT_FAILURE, 0, "%s: currently reading only one image (2d "
-              "array) from a text file is possible, the `info' input has "
+              "array) from a text file is possible, the 'info' input has "
               "more than one element", __func__);
       ndim=2;
       maxcolnum=dsize[1];
       out=gal_data_alloc(NULL, info->type, ndim, dsize, NULL, 0, minmapsize,
-                         info->name, info->unit, info->comment);
+                         quietmmap, info->name, info->unit, info->comment);
       break;
 
 
@@ -992,13 +1010,13 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
 
   /* Allocate the space to keep the pointers to each token in the
      line. This is done here to avoid having to allocate/free this array
-     for each line in `txt_fill_columns'. Note that the column numbers are
+     for each line in 'txt_fill_columns'. Note that the column numbers are
      counted from one (unlike indexes that are counted from zero), so we
-     need `maxcolnum+1' elements in the array of tokens.*/
+     need 'maxcolnum+1' elements in the array of tokens.*/
   errno=0;
   tokens=malloc((maxcolnum+1)*sizeof *tokens);
   if(tokens==NULL)
-    error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for `tokens'",
+    error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for 'tokens'",
           __func__, (maxcolnum+1)*sizeof *tokens);
 
   if(filename)
@@ -1016,7 +1034,7 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
           ++lineno;
           if( gal_txt_line_stat(line) == GAL_TXT_LINESTAT_DATAROW )
             txt_fill(line, tokens, maxcolnum, info, out, rowind++,
-                     filename, lineno, 1);
+                     filename, lineno, 1, format);
         }
 
       /* Clean up and close the file. */
@@ -1032,7 +1050,7 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
         ++lineno;
         if( gal_txt_line_stat(tmp->v) == GAL_TXT_LINESTAT_DATAROW )
           txt_fill(tmp->v, tokens, maxcolnum, info, out, rowind++,
-                   filename, lineno, 0);
+                   filename, lineno, 0, format);
       }
 
   /* Clean up and return. */
@@ -1047,10 +1065,10 @@ txt_read(char *filename, gal_list_str_t *lines, size_t *dsize,
 gal_data_t *
 gal_txt_table_read(char *filename, gal_list_str_t *lines, size_t numrows,
                    gal_data_t *colinfo, gal_list_sizet_t *indexll,
-                   size_t minmapsize)
+                   size_t minmapsize, int quietmmap)
 {
   return txt_read(filename, lines, &numrows, colinfo, indexll, minmapsize,
-                  TXT_FORMAT_TABLE);
+                  quietmmap, TXT_FORMAT_TABLE);
 }
 
 
@@ -1058,7 +1076,8 @@ gal_txt_table_read(char *filename, gal_list_str_t *lines, size_t numrows,
 
 
 gal_data_t *
-gal_txt_image_read(char *filename, gal_list_str_t *lines, size_t minmapsize)
+gal_txt_image_read(char *filename, gal_list_str_t *lines, size_t minmapsize,
+                   int quietmmap)
 {
   size_t numimg, dsize[2];
   gal_data_t *img, *imginfo;
@@ -1069,7 +1088,7 @@ gal_txt_image_read(char *filename, gal_list_str_t *lines, size_t minmapsize)
 
   /* Read the table. */
   img=txt_read(filename, lines, dsize, imginfo, indexll, minmapsize,
-               TXT_FORMAT_IMAGE);
+               quietmmap, TXT_FORMAT_IMAGE);
 
   /* Clean up and return. */
   gal_data_free(imginfo);
@@ -1093,13 +1112,13 @@ txt_stdin_has_contents(long timeout_microsec)
   tv.tv_sec  = 0;
   tv.tv_usec = timeout_microsec;
 
-  /* Initialize `fd_set'. */
+  /* Initialize 'fd_set'. */
   FD_ZERO(&fds);
 
   /* Set standard input (STDIN_FILENO is 0) as the FD that must be read. */
   FD_SET(STDIN_FILENO, &fds);
 
-  /* `select' takes the last file descriptor value + 1 in the fdset to
+  /* 'select' takes the last file descriptor value + 1 in the fdset to
      check, the fdset for reads, writes, and errors.  We are only passing
      in reads.  the last parameter is the timeout.  select will return if
      an FD is ready or the timeout has occurred. */
@@ -1118,22 +1137,22 @@ gal_txt_stdin_read(long timeout_microsec)
 {
   char *line;
   gal_list_str_t *out=NULL;
-  size_t lineno=0, linelen=10;/* `linelen' will be increased by `getline'. */
+  size_t lineno=0, linelen=10;/* 'linelen' will be increased by 'getline'. */
 
   /* If there is nothing  */
   if( txt_stdin_has_contents(timeout_microsec) )
     {
       /* Allocate the space necessary to keep a copy of each line as we
-         parse it. Note that `getline' is going to later `realloc' this
+         parse it. Note that 'getline' is going to later 'realloc' this
          space to fit the line length. */
       errno=0;
       line=malloc(linelen*sizeof *line);
       if(line==NULL)
-        error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for `line'",
+        error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for 'line'",
               __func__, linelen*sizeof *line);
 
       /* Read the whole standard input. We are using getline because it can
-         deal with a `NULL' in the input, while also handing allocation
+         deal with a 'NULL' in the input, while also handing allocation
          issues while reading (allocating by line, not by a fixed buffer
          size). */
       while( getline(&line, &linelen, stdin) != -1 )
@@ -1241,7 +1260,7 @@ make_fmts_for_printf(gal_data_t *datall, int leftadjust, size_t *len)
 
       /* Print the result into the allocated string and add its length to
          the final length of the overall format statement. The space in the
-         end of `fmts[i*2]' is to ensure that the columns don't merge, even
+         end of 'fmts[i*2]' is to ensure that the columns don't merge, even
          if the printed string is larger than the expected width. */
       if(data->disp_precision > 0)
         *len += 1 + sprintf(fmts[i*FMTS_COLS], "%%%s%d.%d%s%s ",
@@ -1334,15 +1353,15 @@ txt_write_metadata(FILE *fp, gal_data_t *datall, char **fmts)
 
 
   /* When there are more than 9 columns, we don't want to have cases
-     like `# Column 1 :' (note the space between `1' and `:', this
+     like '# Column 1 :' (note the space between '1' and ':', this
      space won't exist for the 2 digit colum numbers).
 
      To do this, we are first allocating and printing a string long
-     enough to keep the final column's `N:'. Then, for each column, we
-     print only the number into the allocated space and put the `:' in
+     enough to keep the final column's 'N:'. Then, for each column, we
+     print only the number into the allocated space and put the ':' in
      manually immediately after the number. Note that the initial
-     `asprintf' put a `\0' in the allocated space, so we can safely
-     over-write the one that `sprintf' puts with a `:' for the columns
+     'asprintf' put a '\0' in the allocated space, so we can safely
+     over-write the one that 'sprintf' puts with a ':' for the columns
      that have the same number of digits as the final column. */
   i=0;
   if( asprintf(&nstr, "%zu:", num)<0 )
@@ -1350,7 +1369,7 @@ txt_write_metadata(FILE *fp, gal_data_t *datall, char **fmts)
   nlen=strlen(nstr);
   for(data=datall; data!=NULL; data=data->next)
     {
-      /* Print the number into the number string, then add the `:'
+      /* Print the number into the number string, then add the ':'
          immediately after the number. */
       sprintf(nstr, "%zu", i+1);
       for(j=1;j<nlen;++j)
@@ -1418,7 +1437,7 @@ gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
          elements. */
       if( input!=data && gal_dimension_is_different(input, data) )
         error(EXIT_FAILURE, 0, "%s: the input list of datasets must have the "
-              "same sizes (dimentionality and length along each dimension)",
+              "same sizes (dimensions and length along each dimension)",
               __func__);
     }
 
@@ -1460,14 +1479,26 @@ gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
   switch(input->ndim)
     {
     case 1:
-      for(i=0;i<input->size;++i)                        /* Row.    */
-        {
-          j=0;
-          for(data=input;data!=NULL;data=data->next)    /* Column. */
-            txt_print_value(fp, data->array, data->type, i,
+      /* When the dataset is bring printed on standard output and its a
+         single number, don't print the column structure, because it will
+         add white-space characters which can be annoying when used in an
+         automatic script. */
+      if(fp==stdout && input->size==1 && input->next==NULL)
+        fprintf(fp, "%s\n",
+                gal_type_to_string(input->array, input->type, 0));
+
+      /* Dataset has more than one row AND more than one column, so follow
+         the basic text formatting (like extra white space to keep the
+         columns under each other). */
+      else
+        for(i=0;i<input->size;++i)                        /* Row.    */
+          {
+            j=0;
+            for(data=input;data!=NULL;data=data->next)    /* Column. */
+              txt_print_value(fp, data->array, data->type, i,
                             fmts[j++ * FMTS_COLS]);
-          fprintf(fp, "\n");
-        }
+            fprintf(fp, "\n");
+          }
       break;
 
 
